@@ -1,10 +1,11 @@
 # Defines routine for `amz init`
-import os, getpass
+import os
+import getpass
 from distutils.dir_util import copy_tree
 from distutils.file_util import copy_file
 from configparser import RawConfigParser
-import yaml
 import subprocess as sp
+import yaml
 
 from amz.loading import Loading
 import amz.meta as meta
@@ -133,7 +134,7 @@ def amz_repo_init(verbose=False):
             print("Please run this command from the repo root")
             l.end(1)
             return
-        elif IN_AMZ_ROOT not in ['y', 'n']:
+        if IN_AMZ_ROOT not in ['y', 'n']:
             print("Didn't quite catch you there!")
         else:
             break
@@ -202,7 +203,8 @@ def amz_repo_init(verbose=False):
 
     # Setup githooks
     l.chain("Installing githooks", "\t", 0)
-    if verbose: l.end(-2)
+    if verbose:
+        l.end(-2)
     try:
         # Copy config files to root of repo: pre-commit, clang-format, yapf, cpplint, and pylint
         copy_tree(f'{AMZ_DATA_DIR}/githooks/config/', amz_root_dir)
@@ -222,7 +224,8 @@ def amz_repo_init(verbose=False):
     # Clone submodules
     if os.path.exists(f'{amz_root_dir}/.gitmodules'):
         l.chain("Cloning submodules", "\t", 0)
-        if verbose: l.end(-2)
+        if verbose:
+            l.end(-2)
         try:
             os.chdir(amz_root_dir)
             p = sp.run('git submodule update --init --recursive', shell=True, stdout=sp_channel, stderr=sp_channel)
@@ -239,7 +242,7 @@ def amz_repo_init(verbose=False):
         print("Exiting...")
         l.end(1)
         return
-    elif INSTALL_DEPS not in ['y', 'n']:
+    if INSTALL_DEPS not in ['y', 'n']:
         print("Didn't understand! - Exiting...")
         l.end(1)
         return
@@ -274,4 +277,4 @@ def amz_repo_init(verbose=False):
         l.chain("No Py3 dependencies file found", "\t")
         l.end(1)
 
-    return
\ No newline at end of file
+    return
