@@ -1,6 +1,8 @@
 # Loading Animator
 
-import subprocess, time, sys, threading, os
+import time
+import sys
+import threading
 
 
 class Loading:
@@ -72,4 +74,4 @@ class Loading:
     def end(self, rcode):
         self.retcode = rcode
         while not self.anim_done:
-            time.sleep(0.1)
\ No newline at end of file
+            time.sleep(0.1)
