@@ -4,7 +4,6 @@ from functools import reduce
 from operator import getitem
 from itertools import product
 import subprocess as sp
-
 import yaml
 
 
@@ -32,7 +31,7 @@ def get_amz_config(key_chain):
         config = yaml.load(open(AMZ_CONFIG_FILE, 'r'), Loader=yaml.FullLoader)
         return reduce(getitem, key_chain, config)
     except:
-        return
+        return None
 
 
 def get_yaml_config(filepath, key_chain):
@@ -41,7 +40,7 @@ def get_yaml_config(filepath, key_chain):
         config = yaml.load(open(filepath, 'r'), Loader=yaml.FullLoader)
         return reduce(getitem, key_chain, config)
     except:
-        return
+        return None
 
 
 def highlight_cmd(cmd):
@@ -52,21 +51,27 @@ def validate_script(filepath):
     # Open and parse yaml file
     yf = yaml.load(open(filepath), Loader=yaml.FullLoader)
     # Check for 4 sections - Meta, Install, Update, Remove
-    if list(yf.keys()).sort() != ['meta', 'install', 'update', 'remove'].sort(): return False
+    if list(yf.keys()).sort() != ['meta', 'install', 'update', 'remove'].sort():
+        return False
     # Meta Section
     ## Reqd Keys
-    if 'name' not in list(yf['meta'].keys()): return False
-    if 'check' not in list(yf['meta'].keys()): return False
+    if 'name' not in list(yf['meta'].keys()):
+        return False
+    if 'check' not in list(yf['meta'].keys()):
+        return False
     ## deps keys are known?
     if 'deps' in list(yf['meta'].keys()):
-        if not set(yf['meta']['deps'].keys()).issubset(set(['apt', 'py2', 'py3'])): return False
+        if not set(yf['meta']['deps'].keys()).issubset(set(['apt', 'py2', 'py3'])):
+            return False
     ## args have default keys?
     if 'args' in list(yf['meta'].keys()):
-        if not all('default' in val for val in list(yf['meta']['args'].values())): return False
+        if not all('default' in val for val in list(yf['meta']['args'].values())):
+            return False
     # Install/Update/Remove Section
     for sec in ['install', 'update', 'remove']:
         ## Each dict value is a list of str
-        if not all(all(isinstance(cmd, str) for cmd in cmds) for cmds in list(yf[sec].values())): return False
+        if not all(all(isinstance(cmd, str) for cmd in cmds) for cmds in list(yf[sec].values())):
+            return False
     return True
 
 
@@ -75,7 +80,7 @@ def autocomplete_choices():
         amz_yaml = ''
         p = sp.run('git rev-parse --show-toplevel', shell=True, stdout=sp.PIPE, stderr=sp.PIPE)
         # Check if your current repo is recognized as amz
-        if p.returncode is 0 and os.path.exists(f'{p.stdout.decode()[:-1]}/amz.yaml'):
+        if p.returncode == 0 and os.path.exists(f'{p.stdout.decode()[:-1]}/amz.yaml'):
             amz_yaml = f'{p.stdout.decode()[:-1]}/amz.yaml'
         else:
             amz_yaml = get_amz_config(['amz_repo_meta', 'amz_repo_config'])
@@ -87,7 +92,7 @@ def autocomplete_choices():
         if 'scripts' in auto_yaml.keys() and auto_yaml['scripts'] is not None:
             choices += list(auto_yaml['scripts'].keys())
             for scr in auto_yaml['scripts'].keys():
-                args_avail = get_yaml_config(f'{p.stdout.decode()[:-1]}/{auto_yaml["scripts"][scr]}', ['meta', 'args'])
+                args_avail = get_yaml_config(f'{amz_yaml[:-9]}/{auto_yaml["scripts"][scr]}', ['meta', 'args'])
                 if args_avail is not None:
                     arg_list = [list(args_avail[arg].keys())[1:] for arg in list(args_avail.keys())]
                     choices += [f'{scr}.' + '.'.join(opts) for opts in list(product(*arg_list))]
